@@ -12,22 +12,12 @@ Copyright © Semantyk 2020. All rights reserved.\
 """
 
 __author__ = 'Daniel Bakas Amuchastegui'
+__date__ = '2020-05-21'
 __email__ = 'danielbakas@gmail.com'
-__version__ = '0.0.0.50'
-
-from . import archive
-from . import av_reality
-from . import core
-from . import das
-from . import dots
-from . import dvm
-from . import games
-from . import learn
-from . import sam
-from . import store
-from . import tools
-from . import uuid_generator
+__version__ = '0.0.0.51'
 
+from . import (archive, av_reality, core, das, dots, dvm, games, learn, sam,
+               store, tools, uuid_generator)
 from .archive import *
 from .av_reality import *
 from .core import *
@@ -38,4 +28,4 @@ from .learn import *
 from .sam import *
 from .store import *
 from .tools import *
-from .uuid_generator import *
\ No newline at end of file
+from .uuid_generator import *
