@@ -11,6 +11,8 @@ Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 """
 
-from . import namespace
-
-from .namespace import *
\ No newline at end of file
+from . import graph, identifier, namespace, node
+from .graph import *
+from .identifier import *
+from .namespace import *
+from .node import *
