@@ -1,14 +1,29 @@
 # -*- coding: utf-8 -*-
-##################################################
-#
-# namespace 
-# Module | Namespace
-#
-# Author: Daniel Bakas Amuchastegui
-# August 31, 2017
-# 
-# Copyright © Semantyk 2020. All rights reserved.
-##################################################
+"""
+–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
+# Namespace
+Module | `namespace.py`
+
+Daniel Bakas Amuchastegui\
+May 21, 2020
+
+Copyright © Semantyk 2020. All rights reserved.\
+–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
+"""
+
+__all__ = [
+    'DC',
+    'DCTERMS',
+    'DOAP',
+    'FOAF',
+    'OWL',
+    'RDF',
+    'RDFS',
+    'SMTK',
+    'SKOS',
+    'XSD',
+    'VOID'
+]
 
 from rdflib import Namespace
 
