@@ -11,9 +11,6 @@ Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 """
 
-
-from . import genealogical_tree
-from . import network
-
+from . import genealogical_tree, network
 from .genealogical_tree import *
-from .network import *
\ No newline at end of file
+from .network import *
