@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
-##################################################
-#
-# uuid_generator
-# Module | UUID Generator
-#
-# Daniel Bakas Amuchastegui
-# March 16, 2020
-# 
-# Copyright © Semantyk 2020. All rights reserved.
-##################################################
+"""
+–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
+# UUID Generator  
+Module | `uuid_generator.py`
+
+Daniel Bakas Amuchastegui\
+March 16, 2020
+
+Copyright © Semantyk 2020. All rights reserved.\
+–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
+"""
 
 import uuid
 
